==> peloton-pycassa-0.0.0.tar.gz: peloton-pycassa-0.0.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os

try:
    import subprocess
    has_subprocess = True
except:
    has_subprocess = False


try:
    from ez_setup import use_setuptools
    use_setuptools()
except ImportError:
    pass

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

from distutils.cmd import Command

__version__ = "0.0.0"

long_description = """pycassa is a python client library for Apache Cassandra with the following features:

1. Auto-failover single or thread-local connections
2. Connection pooling
3. A batch interface
4. Simplified version of the Thrift interface
5. A method to map an existing class to a Cassandra column family
"""


class rpm(Command):

    description = "builds a RPM package"

    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        if has_subprocess:
            status = subprocess.call(["python", "setup.py", "bdist_rpm", "--install-script", "rpm-install-script.sh"])

            if status:
                raise RuntimeError("RPM build failed")

            print ""
            print "RPM built"
        else:
            print """
`setup.py rpm` is not supported for this version of Python.

Please ask in the user forums for help.
"""

class doc(Command):

    description = "generate or test documentation"

    user_options = [("test", "t",
                     "run doctests instead of generating documentation")]

    boolean_options = ["test"]

    def initialize_options(self):
        self.test = False

    def finalize_options(self):
        pass

    def run(self):
        if self.test:
            path = "doc/_build/doctest"
            mode = "doctest"
        else:
            path = "doc/_build/%s" % __version__
            mode = "html"

            try:
                os.makedirs(path)
            except:
                pass

        if has_subprocess:
            status = subprocess.call(["sphinx-build", "-b", mode, "doc", path])

            if status:
                raise RuntimeError("documentation step '%s' failed" % mode)

            print ""
            print "Documentation step '%s' performed, results here:" % mode
            print "   %s/" % path
        else:
            print """
`setup.py doc` is not supported for this version of Python.

Please ask in the user forums for help.
"""


setup(
      name = 'peloton-pycassa',
      version = __version__,
      author = 'Jonathan Hseu',
      author_email = 'vomjom AT vomjom.net',
      maintainer = 'Adam DePrince',
      maintainer_email = 'adam@pelotoncycle.com',
      description = 'Peloton fork of Python client library for Apache Cassandra.  This is not the pycassa you want.',
      long_description = long_description,
      url = 'http://github.com//pycassa',
      keywords = ['pycassa', 'cassandra', 'client', 'driver', 'db', 'distributed', 'thrift'],
      packages = ['pycassa',
                  'pycassa.cassandra',
                  'pycassa.logging',
                  'pycassa.contrib'],
      tests_require = ['nose'],
      install_requires = ['thrift'],
      py_modules=['ez_setup'],
      scripts=['pycassaShell'],
      cmdclass={"doc": doc, "rpm": rpm},
      classifiers=[
          ]
      )

==> peloton-pycassa-1.11.0.post.tar.gz: peloton-pycassa-1.11.0.post/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os

try:
    import subprocess
    has_subprocess = True
except:
    has_subprocess = False


try:
    from ez_setup import use_setuptools
    use_setuptools()
except ImportError:
    pass

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

from distutils.cmd import Command

__version__ = "1.11.0.post"

long_description = """pycassa is a python client library for Apache Cassandra with the following features:

1. Auto-failover single or thread-local connections
2. Connection pooling
3. A batch interface
4. Simplified version of the Thrift interface
5. A method to map an existing class to a Cassandra column family
"""


class rpm(Command):

    description = "builds a RPM package"

    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        if has_subprocess:
            status = subprocess.call(["python", "setup.py", "bdist_rpm", "--install-script", "rpm-install-script.sh"])

            if status:
                raise RuntimeError("RPM build failed")

            print ""
            print "RPM built"
        else:
            print """
`setup.py rpm` is not supported for this version of Python.

Please ask in the user forums for help.
"""

class doc(Command):

    description = "generate or test documentation"

    user_options = [("test", "t",
                     "run doctests instead of generating documentation")]

    boolean_options = ["test"]

    def initialize_options(self):
        self.test = False

    def finalize_options(self):
        pass

    def run(self):
        if self.test:
            path = "doc/_build/doctest"
            mode = "doctest"
        else:
            path = "doc/_build/%s" % __version__
            mode = "html"

            try:
                os.makedirs(path)
            except:
                pass

        if has_subprocess:
            status = subprocess.call(["sphinx-build", "-b", mode, "doc", path])

            if status:
                raise RuntimeError("documentation step '%s' failed" % mode)

            print ""
            print "Documentation step '%s' performed, results here:" % mode
            print "   %s/" % path
        else:
            print """
`setup.py doc` is not supported for this version of Python.

Please ask in the user forums for help.
"""


setup(
      name = 'peloton-pycassa',
      version = __version__,
      author = 'Jonathan Hseu',
      author_email = 'vomjom AT vomjom.net',
      maintainer = 'Adam DePrince',
      maintainer_email = 'adam@pelotoncycle.com',
      description = 'Peloton fork of Python client library for Apache Cassandra.  This is not the pycassa you want.',
      long_description = long_description,
      url = 'http://github.com//pycassa',
      keywords = ['pycassa', 'cassandra', 'client', 'driver', 'db', 'distributed', 'thrift'],
      packages = ['pycassa',
                  'pycassa.cassandra',
                  'pycassa.logging',
                  'pycassa.contrib'],
      tests_require = ['nose'],
      install_requires = ['thrift'],
      py_modules=['ez_setup'],
      scripts=['pycassaShell'],
      cmdclass={"doc": doc, "rpm": rpm},
      classifiers=[
          ]
      )
